import { message } from 'antd'
import router from '../router/index.tsx'
import http from './index'
import { userLogin } from './api.ts'

type UserInfo = { 
  name: string,
  token: string
}

export function getUserInfo(): UserInfo {
  const activeUser = localStorage.getItem('userInfo')
  return activeUser ? JSON.parse(activeUser) : { name: '', token: '' }
}

export function getAccessToken(): string {
  const userInfo = getUserInfo()
  return userInfo.token
}

export function setUserInfo(userInfo: UserInfo): void {
  localStorage.removeItem('userInfo')
  localStorage.setItem('userInfo', JSON.stringify(userInfo))
}

export function clearUserInfo() {
  localStorage.removeItem('userInfo')
}

export async function login(account: string, password: string) {
  return http.post<UserInfo>(userLogin, {
    account: account,
    password: password
  }).then((res: ApiResponse<UserInfo>) => {
    const { code, msg, data } = res
    if (code === 0) {
      message.success('登录成功')
      setUserInfo(data)
      location.href = '/account/list'
      return true
    }

    message.error(msg)
    return false

  }).catch(() => {})
}

export function logout() {
  message.success('已退出登录')
  clearUserInfo()
  router.navigate('/login')
  return true
}

export default {
  getUserInfo,
  setUserInfo,
  clearUserInfo,
  login,
  logout,
}
